@@ -8,11 +8,13 @@
 #include <QFile>
 #include <QFileSystemWatcher>
 #include <QSettings>
-#include <QList>
+#include <QStringList>
 #include <QString>
 #include <QTextStream>
 #include <QTimer>
+#include <QDateTime>
 
+#define APP_VERSION "0.1.6"
 #define BUS_NAME "com.nokia.csd.Call"
 #define BUS_PATH "/com/nokia/csd/call"
 #define INSTANCE_INTERFACE "com.nokia.csd.Call.Instance"
@@ -40,22 +42,26 @@ public slots:
     Q_SCRIPTABLE void loadwhitelist();
     Q_SCRIPTABLE void loadblacklist();
     Q_SCRIPTABLE void addrecentnumber();
+    Q_SCRIPTABLE QString ping();
 
 private slots:
+    void readSettings();
+    void saveSettings();
     void initialize();
     void callScreen(const QDBusObjectPath&, const QString&);
     void callRelease(const QString&);
-    void loadlist();
-    void updatelist();
-    void setloadlist(const QString&, bool m);
-    void addtolist(const QString&);
+    void loadList();
+    void updateList();
+    void setLoadList(const QString&, bool m);
+    void addToList(const QString&);
     bool isBlocked(const QString&);
+    void logNumber();
+    void sendSignal();
 
 private:
     QFileSystemWatcher* fileWatcher;
-    QList<QString> nlist;
-    QString listPath, whitelistpath, blacklistpath, n, callPath;
-    bool whitelistmode, activetimer;
-    QSettings settings;
+    QStringList nList, callHistory;
+    QString listPath, whitelistPath, blacklistPath, n, callPath, lastInNumber;
+    bool whitelistMode, activeTimer, autoStart, isRunning, blockUnknown;
 };
 #endif // DAEMON_H
