@@ -1,4 +1,4 @@
-#include "mainwindow.h"
+#include "daemon.h"
 #include <QCoreApplication>
 
 int main(int argc, char *argv[])
